// SVNProperty.h : Declaration of the SVNProperty

#pragma once
#include "resource.h"       // main symbols

#include "apr_general.h"
#include "svn_pools.h"
#include "svn_client.h"
#include "svn_utf.h"


[
	object,
	uuid("E1314EEB-A34A-4FF4-ACAE-2ED7153B8A9F"),
	dual,	helpstring("ISVNProperty Interface"),
	pointer_default(unique)
]
__interface ISVNProperty : IDispatch
{
	[propget, id(1), helpstring("property Name")] HRESULT Name([out, retval] BSTR* pVal);
	[propput, id(1), helpstring("property Name")] HRESULT Name([in] BSTR newVal);
	[propget, id(2), helpstring("property Value")] HRESULT Value([out, retval] BSTR* pVal);
	[propput, id(2), helpstring("property Value")] HRESULT Value([in] BSTR newVal);
	[propget, id(3), helpstring("is it an internal subversion property?")] HRESULT IsSVNProperty([out, retval] VARIANT_BOOL* pVal);
};




/**
 * \ingroup SVNCOM
 *
 * Contains the name/value pair which represents a subversion
 * property.
 *
 * \version 1.0
 * first version
 *
 * \date 09-27-2002
 *
 * \author kueng
 *
 * \par license
 * This code is absolutely free to use and modify. The code is provided "as is" with
 * no expressed or implied warranty. The author accepts no liability if it causes
 * any damage to your computer, causes your pet to fall ill, increases baldness
 * or makes your car start emitting strange noises when you start it up.
 * This code has no bugs, just undocumented features!
 * 
 * \todo 
 *
 * \bug 
 *
 */
[
	coclass,
	threading("apartment"),
	vi_progid("SVNCOM.SVNProperty"),
	progid("SVNCOM.SVNProperty.1"),
	version(1.0),
	uuid("B97F7006-5A4E-4BC1-9EE8-955E768A310D"),
	helpstring("SVNProperty Class")
]
class ATL_NO_VTABLE SVNProperty : 
	public ISVNProperty
{
public:
	SVNProperty()
	{
	}


	DECLARE_PROTECT_FINAL_CONSTRUCT()

	HRESULT FinalConstruct()
	{
		pool = svn_pool_create (NULL);
		return S_OK;
	}
	
	void FinalRelease() 
	{
		svn_pool_destroy (pool);
	}

private:
	apr_pool_t*				pool;
public:
	CString					name;
	CString					value;

public:

	STDMETHOD(get_Name)(BSTR* pVal);
	STDMETHOD(put_Name)(BSTR newVal);
	STDMETHOD(get_Value)(BSTR* pVal);
	STDMETHOD(put_Value)(BSTR newVal);
	/**
	 * Checks if the property is an internal subversion
	 * property or a user defined property.
	 * \param pVal TRUE if its a subversion property, false for a user defined property
	 */
	STDMETHOD(get_IsSVNProperty)(VARIANT_BOOL* pVal);
};

